Index: /trunk/psLib/test/collections/Makefile
===================================================================
--- /trunk/psLib/test/collections/Makefile	(revision 687)
+++ /trunk/psLib/test/collections/Makefile	(revision 688)
@@ -3,6 +3,6 @@
 ##  Makefile:   test/collections
 ##
-##  $Revision: 1.2 $  $Name: not supported by cvs2svn $
-##  $Date: 2004-05-06 23:23:02 $
+##  $Revision: 1.3 $  $Name: not supported by cvs2svn $
+##  $Date: 2004-05-14 21:04:23 $
 ##
 ##  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -16,10 +16,7 @@
 PSLIB_LIB_DIR = ../../lib
 
-TARGET = tst_psArray_01  \
-         tst_psArray_02  \
-         tst_psArray_03  \
-         tst_psArray_04  \
-         tst_psArray_05  \
-         tst_psArray_06  \
+TARGET = tst_psVector_01 \
+         tst_psVector_02 \
+         tst_psVector_03 \
          tst_psBitSet_01 \
          tst_psBitSet_02 \
@@ -35,10 +32,7 @@
 all: $(TARGET)
 
-tst_psArray_01: tst_psArray_01.o
-tst_psArray_02: tst_psArray_02.o
-tst_psArray_03: tst_psArray_03.o
-tst_psArray_04: tst_psArray_04.o
-tst_psArray_05: tst_psArray_05.o
-tst_psArray_06: tst_psArray_06.o
+tst_psVector_01: tst_psVector_01.o
+tst_psVector_02: tst_psVector_02.o
+tst_psVector_03: tst_psVector_03.o
 tst_psBitSet_01: tst_psBitSet_01.o
 tst_psBitSet_02: tst_psBitSet_02.o
Index: unk/psLib/test/collections/tst_psArray_01.c
===================================================================
--- /trunk/psLib/test/collections/tst_psArray_01.c	(revision 687)
+++ 	(revision )
@@ -1,77 +1,0 @@
-/** @file  tst_psArray_01.c
- *
- *  @brief Test driver for psArray integer functions
- *
- *  This test driver contains the following tests for psArray test point 1:
- *     A)  Create integer array
- *     B)  Add data to integer array
- *     C)  Reallocate integer array bigger
- *     D)  Reallocate integer array smaller
- *     E)  Free integer array
- *
- *  @author  Ross Harman, MHPCC
- *
- *  @version $Revision: 1.2 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-08 01:19:28 $
- *
- *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
- *
- */
-
-#include "psLib.h"
-#include "psTest.h"
-
-int main(int argc,
-         char* argv[])
-{
-
-    // Test A - Create integer array
-    printPositiveTestHeader(stdout,"psArray", "Create integer array");
-    psArray *psArr = psIntArrayAlloc(5);
-    printf("Array size = %d\n", psArr->nalloc);
-    printFooter(stdout, "psArray", "Create integer array", true);
-
-
-    // Test B - Add data to integer array
-    printPositiveTestHeader(stdout, "psArray", "Add data to integer array");
-    for(int i = 0; i < 5; i++) {
-        psArr->arr.intArr[i] = i*10;
-        printf("Elem %d = %d\n", i, psArr->arr.intArr[i]);
-    }
-    printFooter(stdout, "psArray", "Add data to integer array", true);
-
-
-    // Test C - Reallocate integer array bigger
-    printPositiveTestHeader(stdout,"psArray", "Reallocate integer array bigger");
-    psArr = psIntArrayRealloc(psArr, 10);
-    printf("Array size = %d\n", psArr->nalloc);
-    printf("\nAdding more elements to integer array...\n");
-    for(int i = 5; i < 10; i++) {
-        psArr->arr.intArr[i] = i*10;
-        printf("Elem %d = %d\n", i, psArr->arr.intArr[i]);
-    }
-    printFooter(stdout, "psArray", "Reallocate integer array bigger", true);
-
-
-    // Test D - Reallocate integer array smaller
-    printPositiveTestHeader(stdout,"psArray","Reallocate integer array smaller");
-    psArr = psIntArrayRealloc(psArr, 3);
-    printf("Array size = %d\n", psArr->nalloc);
-    for(int i = 0; i < 3; i++) {
-        printf("Elem %d = %d\n", i, psArr->arr.intArr[i]);
-    }
-    printFooter(stdout, "psArray", "Reallocate integer array smaller", true);
-
-
-    // Test E - Free integer array
-    printPositiveTestHeader(stdout, "psArray", "Free integer array");
-    psIntArrayFree(psArr);
-    psMemCheckLeaks(0, NULL, stdout);
-    int nBad = psMemCheckCorruption(0);
-    if(nBad) {
-        printf("ERROR: Found %d bad memory blocks\n", nBad);
-    }
-    printFooter(stdout, "psArray" ,"Free integer array", true);
-
-    return 0;
-}
Index: unk/psLib/test/collections/tst_psArray_02.c
===================================================================
--- /trunk/psLib/test/collections/tst_psArray_02.c	(revision 687)
+++ 	(revision )
@@ -1,79 +1,0 @@
-/** @file  tst_psArray_02.c
- *
- *  @brief Test driver for psArray float functions
- *
- *  This test driver contains the following tests for psArray test point 2:
- *     A)  Create float array
- *     B)  Add data to float array
- *     C)  Reallocate float array bigger
- *     D)  Reallocate float array smaller
- *     E)  Free float array
- *
- *  @author  Ross Harman, MHPCC
- *
- *  @version $Revision: 1.2 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-08 01:19:28 $
- *
- *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
- *
- */
-
-#include <stdio.h>
-#include "psLib.h"
-#include "psTest.h"
-
-int main(int argc,
-         char* argv[])
-{
-
-    // Test A - Create float array
-    printPositiveTestHeader(stdout,"psArray","Create float array");
-    psArray *psArr = psFloatArrayAlloc(5);
-    printf("Array size = %d\n", psArr->nalloc);
-    printFooter(stdout, "psArray","Create float array",true);
-
-
-    // Test B - Add data to float array
-    printPositiveTestHeader(stdout,"psArray","Add data to float array");
-    for(int i = 0; i < 5; i++) {
-        psArr->arr.fltArr[i] = i*10.1f;
-        printf("Elem %d = %.2f\n", i, psArr->arr.fltArr[i]);
-    }
-    printFooter(stdout, "psArray","Add data to float array",true);
-
-
-    // Test C - Reallocate float array bigger
-    printPositiveTestHeader(stdout,"psArray","Reallocate float array bigger");
-    psArr = psFloatArrayRealloc(psArr, 10);
-    printf("Array size = %d\n", psArr->nalloc);
-
-    printf("\nAdding more elements to float array...\n");
-    for(int i = 5; i < 10; i++) {
-        psArr->arr.fltArr[i] = i*10.1f;
-        printf("Elem %d = %.2f\n", i, psArr->arr.fltArr[i]);
-    }
-    printFooter(stdout, "psArray","Reallocate float array bigger",true);
-
-
-    // Test D - Reallocate float array smaller
-    printPositiveTestHeader(stdout,"psArray","Reallocate float array smaller");
-    psArr = psFloatArrayRealloc(psArr, 3);
-    printf("Array size = %d\n", psArr->nalloc);
-    for(int i = 0; i < 3; i++) {
-        printf("Elem %d = %.2f\n", i, psArr->arr.fltArr[i]);
-    }
-    printFooter(stdout, "psArray","Reallocate float array smaller",true);
-
-
-    // Test E - Free float array
-    printPositiveTestHeader(stdout,"psArray","Free float array");
-    psFloatArrayFree(psArr);
-    psMemCheckLeaks(0, NULL, stdout);
-    int nBad = psMemCheckCorruption(0);
-    if(nBad) {
-        printf("ERROR: Found %d bad memory blocks\n", nBad);
-    }
-    printFooter(stdout, "psArray","Free float array",true);
-
-    return 0;
-}
Index: unk/psLib/test/collections/tst_psArray_03.c
===================================================================
--- /trunk/psLib/test/collections/tst_psArray_03.c	(revision 687)
+++ 	(revision )
@@ -1,78 +1,0 @@
-/** @file  tst_psArray_03.c
- *
- *  @brief Test driver for psArray double functions
- *
- *  This test driver contains the following tests for psArray test point 3:
- *     A)  Create double array
- *     B)  Add data to double array
- *     C)  Reallocate double array bigger
- *     D)  Reallocate double array smaller
- *     E)  Free double array
- *
- *  @author  Ross Harman, MHPCC
- *
- *  @version $Revision: 1.2 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-08 01:19:28 $
- *
- *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
- *
- */
-
-#include <stdio.h>
-#include "psLib.h"
-#include "psTest.h"
-
-int main(int argc,
-         char* argv[])
-{
-
-    // Test A - Create double array
-    printPositiveTestHeader(stdout,"psArray","Create double array");
-    psArray *psArr = psDoubleArrayAlloc(5);
-    printf("Array size = %d\n", psArr->nalloc);
-    printFooter(stdout, "psArray","Create double array",true);
-
-
-    // Test B - Add data to double array
-    printPositiveTestHeader(stdout,"psArray","Add data to double array");
-    for(int i = 0; i < 5; i++) {
-        psArr->arr.dblArr[i] = i*10.1;
-        printf("Elem %d = %.2f\n", i, psArr->arr.dblArr[i]);
-    }
-    printFooter(stdout, "psArray","Add data to double array",true);
-
-
-    // Test C - Reallocate double array bigger
-    printPositiveTestHeader(stdout,"psArray","Reallocate double array bigger");
-    psArr = psDoubleArrayRealloc(psArr, 10);
-    printf("Array size = %d\n", psArr->nalloc);
-    printf("\nAdding more elements to double array...\n");
-    for(int i = 5; i < 10; i++) {
-        psArr->arr.dblArr[i] = i*10.1;
-        printf("Elem %d = %.2f\n", i, psArr->arr.dblArr[i]);
-    }
-    printFooter(stdout, "psArray","Reallocate double array bigger",true);
-
-
-    // Test D - Reallocate double array smaller
-    printPositiveTestHeader(stdout,"psArray","Reallocate double array smaller");
-    psArr = psDoubleArrayRealloc(psArr, 3);
-    printf("Array size = %d\n", psArr->nalloc);
-    for(int i = 0; i < 3; i++) {
-        printf("Elem %d = %.2f\n", i, psArr->arr.dblArr[i]);
-    }
-    printFooter(stdout, "psArray","Reallocate double array smaller",true);
-
-
-    // Test E - Free double array
-    printPositiveTestHeader(stdout,"psArray","Free double array");
-    psDoubleArrayFree(psArr);
-    psMemCheckLeaks(0, NULL, stdout);
-    int nBad = psMemCheckCorruption(0);
-    if(nBad) {
-        printf("ERROR: Found %d bad memory blocks\n", nBad);
-    }
-    printFooter(stdout, "psArray","Free double array",true);
-
-    return 0;
-}
Index: unk/psLib/test/collections/tst_psArray_04.c
===================================================================
--- /trunk/psLib/test/collections/tst_psArray_04.c	(revision 687)
+++ 	(revision )
@@ -1,78 +1,0 @@
-/** @file  tst_psArray_04.c
- *
- *  @brief Test driver for psArray complex functions
- *
- *  This test driver contains the following tests for psArray test point 4:
- *     A)  Create complex array
- *     B)  Add data to complex array
- *     C)  Reallocate complex array bigger
- *     D)  Reallocate complex array smaller
- *     E)  Free complex array
- *
- *  @author  Ross Harman, MHPCC
- *
- *  @version $Revision: 1.2 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-08 01:19:28 $
- *
- *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
- *
- */
-
-#include <stdio.h>
-#include "psLib.h"
-#include "psTest.h"
-
-int main(int argc,
-         char* argv[])
-{
-
-    // Test A - Create complex array
-    printPositiveTestHeader(stdout,"psArray","Create complex array");
-    psArray *psArr = psComplexArrayAlloc(5);
-    printf("Array size = %d\n", psArr->nalloc);
-    printFooter(stdout, "psArray","Create complex array",true);
-
-
-    // Test B - Add data to complex array
-    printPositiveTestHeader(stdout,"psArray","Add data to complex array");
-    for(int i = 0; i < 5; i++) {
-        psArr->arr.cFltArr[i] = 10.1f*i+10.1f*i*I;
-        printf("Elem %d = %.2f+%.2fi\n", i, crealf(psArr->arr.cFltArr[i]), cimagf(psArr->arr.cFltArr[i]));
-    }
-    printFooter(stdout, "psArray","Add data to complex array",true);
-
-
-    // Test C - Reallocate complex array bigger
-    printPositiveTestHeader(stdout,"psArray","Reallocate complex array bigger");
-    psArr = psComplexArrayRealloc(psArr, 10);
-    printf("Array size = %d\n", psArr->nalloc);
-    printf("\nAdding more elements to complex array...\n");
-    for(int i = 5; i < 10; i++) {
-        psArr->arr.cFltArr[i] = 10.1f*i+10.1f*i*I;
-        printf("Elem %d = %.2f+%.2fi\n", i, crealf(psArr->arr.cFltArr[i]), cimagf(psArr->arr.cFltArr[i]));
-    }
-    printFooter(stdout, "psArray","Reallocate complex array bigger",true);
-
-
-    // Test D - Reallocate complex array smaller
-    printPositiveTestHeader(stdout,"psArray","Reallocate complex array smaller");
-    psArr = psComplexArrayRealloc(psArr, 3);
-    printf("Array size = %d\n", psArr->nalloc);
-    for(int i = 0; i < 3; i++) {
-        printf("Elem %d = %.2f+%.2fi\n", i, crealf(psArr->arr.cFltArr[i]), cimagf(psArr->arr.cFltArr[i]));
-    }
-    printFooter(stdout, "psArray","Reallocate complex array smaller",true);
-
-
-    // Test E - Free complex array
-    printPositiveTestHeader(stdout,"psArray","Free complex array");
-    psComplexArrayFree(psArr);
-    psMemCheckLeaks(0, NULL, stdout);
-    int nBad = psMemCheckCorruption(0);
-    if(nBad) {
-        printf("ERROR: Found %d bad memory blocks\n", nBad);
-    }
-    printFooter(stdout, "psArray","Free complex array",true);
-
-    return 0;
-}
Index: unk/psLib/test/collections/tst_psArray_05.c
===================================================================
--- /trunk/psLib/test/collections/tst_psArray_05.c	(revision 687)
+++ 	(revision )
@@ -1,111 +1,0 @@
-/** @file  tst_psArray_05.c
- *
- *  @brief Test driver for psArray complex functions
- *
- *  This test driver contains the following tests for psArray test point 5:
- *     A)  Create void pointer array
- *     B)  Add data to void pointer array
- *     C)  Reallocate void pointer array bigger
- *     D)  Reallocate void pointer array smaller
- *     E)  Free void pointer array
- *
- *  @author  Ross Harman, MHPCC
- *
- *  @version $Revision: 1.2 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-08 01:19:28 $
- *
- *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
- *
- */
-
-#include <stdio.h>
-#include "psLib.h"
-#include "psTest.h"
-
-typedef struct
-{
-    int x;
-    float y;
-}
-testStruct;
-
-
-int main(int argc,
-         char* argv[])
-{
-    // Create array of pointers
-    testStruct *mySt[10];
-
-
-    // Test A - Create void pointer array
-    printPositiveTestHeader(stdout,"psArray", "Create void pointer array");
-    psArray *psArr = psVoidPtrArrayAlloc(5);
-    printf("Array size = %d\n", psArr->nalloc);
-    psArr->n = 5;
-    printFooter(stdout, "psArray", "Create void pointer array", true);
-
-
-    // Test B - Add data to void pointer array
-    printPositiveTestHeader(stdout, "psArray", "Add data to void pointer array");
-    for(int i = 0; i < 5; i++) {
-        testStruct *ts = psAlloc(sizeof(testStruct));
-        ts->x = 10*i;
-        ts->y = 10.1*i;
-        mySt[i] = ts;
-        psArr->arr.ptrArr[i] = ts;
-        psMemIncrRefCounter(ts);
-    }
-
-    for(int i = 0; i < 5; i++) {
-        testStruct *ts = psArr->arr.ptrArr[i];
-        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
-    }
-    printFooter(stdout, "psArray", "Add data to void pointer array", true);
-
-
-    // Test C - Reallocate void pointer array bigger
-    printPositiveTestHeader(stdout,"psArray","Reallocate void pointer array bigger");
-    psArr = psVoidPtrArrayRealloc(psArr, 10);
-    psArr->n=10;
-    printf("Array size = %d\n", psArr->nalloc);
-    for(int i = 5; i < 10; i++) {
-        testStruct *ts = psAlloc(sizeof(testStruct));
-        ts->x = 10*i;
-        ts->y = 10.1*i;
-        mySt[i] = ts;
-        psArr->arr.ptrArr[i] = ts;
-        psMemIncrRefCounter(ts);
-    }
-    for(int i = 0; i < 10; i++) {
-        testStruct *ts = psArr->arr.ptrArr[i];
-        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
-    }
-    printFooter(stdout, "psArray", "Reallocate void pointer array bigger", true);
-
-
-    // Test D - Reallocate void pointer array smaller
-    printPositiveTestHeader(stdout, "psArray", "Reallocate void pointer array smaller");
-    psArr = psVoidPtrArrayRealloc(psArr, 3);
-    printf("Array size = %d\n", psArr->nalloc);
-    for(int i = 0; i < 3; i++) {
-        testStruct *ts = psArr->arr.ptrArr[i];
-        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
-    }
-    printFooter(stdout, "psArray", "Reallocate void pointer array smaller",true);
-
-
-    // Test E - Free void pointer array
-    printPositiveTestHeader(stdout, "psArray", "Free void pointer array");
-    psVoidPtrArrayFree(psArr, NULL);
-    for(int i = 0; i < 10; i++) {
-        psFree(mySt[i]);
-    }
-    psMemCheckLeaks(0, NULL, stdout);
-    int nBad = psMemCheckCorruption(0);
-    if(nBad) {
-        printf("ERROR: Found %d bad memory blocks\n", nBad);
-    }
-    printFooter(stdout, "psArray", "Free void pointer array", true);
-
-    return 0;
-}
Index: unk/psLib/test/collections/tst_psArray_06.c
===================================================================
--- /trunk/psLib/test/collections/tst_psArray_06.c	(revision 687)
+++ 	(revision )
@@ -1,120 +1,0 @@
-/** @file  tst_psArray_05.c
- *
- *  @brief Test driver for psArray complex functions
- *
- *  This test driver contains the following tests for psArray test point 5:
- *     A)  Create void pointer array
- *     B)  Add data to void pointer array
- *     C)  Reallocate void pointer array bigger
- *     D)  Reallocate void pointer array smaller
- *     E)  Free void pointer array with function callback
- *
- *  @author  Ross Harman, MHPCC
- *
- *  @version $Revision: 1.2 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-08 01:19:28 $
- *
- *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
- *
- */
-
-#include <stdio.h>
-#include "psLib.h"
-#include "psTest.h"
-
-typedef struct
-{
-    int x;
-    float y;
-}
-testStruct;
-
-
-static void freeData(void *data)
-{
-    psFree(data);
-}
-
-int main(int argc,
-         char* argv[])
-{
-    // Create array of pointers
-    testStruct *mySt[10];
-
-
-    // Test A - Create void pointer array
-    printPositiveTestHeader(stdout,"psArray", "Create void pointer array");
-    psArray *psArr = psVoidPtrArrayAlloc(5);
-    printf("Array size = %d\n", psArr->nalloc);
-    psArr->n = 5;
-    printFooter(stdout, "psArray", "Create void pointer array", true);
-
-
-    // Test B - Add data to void pointer array
-    printPositiveTestHeader(stdout, "psArray", "Add data to void pointer array");
-    for(int i = 0; i < 5; i++) {
-        testStruct *ts = psAlloc(sizeof(testStruct));
-        ts->x = 10*i;
-        ts->y = 10.1*i;
-        mySt[i] = ts;
-        psArr->arr.ptrArr[i] = ts;
-        psMemIncrRefCounter(ts);
-    }
-
-    for(int i = 0; i < 5; i++) {
-        testStruct *ts = psArr->arr.ptrArr[i];
-        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
-    }
-    printFooter(stdout, "psArray", "Add data to void pointer array", true);
-
-
-    // Test C - Reallocate void pointer array bigger
-    printPositiveTestHeader(stdout,"psArray","Reallocate void pointer array bigger");
-    psArr = psVoidPtrArrayRealloc(psArr, 10);
-    psArr->n=10;
-    printf("Array size = %d\n", psArr->nalloc);
-    for(int i = 5; i < 10; i++) {
-        testStruct *ts = psAlloc(sizeof(testStruct));
-        ts->x = 10*i;
-        ts->y = 10.1*i;
-        mySt[i] = ts;
-        psArr->arr.ptrArr[i] = ts;
-        psMemIncrRefCounter(ts);
-    }
-    for(int i = 0; i < 10; i++) {
-        testStruct *ts = psArr->arr.ptrArr[i];
-        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
-    }
-    printFooter(stdout, "psArray", "Reallocate void pointer array bigger", true);
-
-
-    // Test D - Reallocate void pointer array smaller
-    printPositiveTestHeader(stdout, "psArray", "Reallocate void pointer array smaller");
-    psArr = psVoidPtrArrayRealloc(psArr, 3);
-    printf("Array size = %d\n", psArr->nalloc);
-    for(int i = 0; i < 3; i++) {
-        testStruct *ts = psArr->arr.ptrArr[i];
-        printf("ts[%d].x = %d ts[%d].y = %.2f\n", i, ts->x, i, ts->y);
-    }
-    printFooter(stdout, "psArray", "Reallocate void pointer array smaller",true);
-
-
-    // Test E - Free void pointer array
-    printPositiveTestHeader(stdout, "psArray", "Free void pointer array with function callback");
-
-    // Free void pointer array struct and its 3 internal elements
-    psVoidPtrArrayFree(psArr, freeData);
-
-    // Free 7 elements manually that were lost after array was reallocated smaller
-    for(int i = 3; i < 10; i++) {
-        psFree(mySt[i]);
-    }
-    psMemCheckLeaks(0, NULL, stdout);
-    int nBad = psMemCheckCorruption(0);
-    if(nBad) {
-        printf("ERROR: Found %d bad memory blocks\n", nBad);
-    }
-    printFooter(stdout, "psArray", "Free void pointer array with function callback", true);
-
-    return 0;
-}
Index: /trunk/psLib/test/collections/tst_psSort_01.c
===================================================================
--- /trunk/psLib/test/collections/tst_psSort_01.c	(revision 687)
+++ /trunk/psLib/test/collections/tst_psSort_01.c	(revision 688)
@@ -4,12 +4,12 @@
  *
  *  This test driver contains the following tests for psSort test point 1:
  *     A)  Create float arrays
  *     B)  Sort input float array and put results into output float array
  *     C)  Free float arrays
  *
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.2 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-08 01:19:28 $
+ *  @version $Revision: 1.3 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-05-14 21:04:23 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -23,38 +23,38 @@
          char* argv[])
 {
-    psArray *in = NULL;
-    psArray *out = NULL;
+    psVector *in = NULL;
+    psVector *out = NULL;
 
 
-    // Test A - Create float arrays
-    printPositiveTestHeader(stdout,"psSort", "Create float arrays");
-    in = psFloatArrayAlloc(5);
+    // Test A - Create float vectors
+    printPositiveTestHeader(stdout,"psSort", "Create float vectors");
+    in = psVectorAlloc(PS_TYPE_FLOAT, 5);
     in->n = 5;
-    out = psFloatArrayAlloc(5);
+    out = psVectorAlloc(PS_TYPE_FLOAT, 5);
     out->n = 5;
-    in->arr.fltArr[0] = 7.0f;
-    in->arr.fltArr[1] = 9.0f;
-    in->arr.fltArr[2] = 3.0f;
-    in->arr.fltArr[3] = 1.0f;
-    in->arr.fltArr[4] = 5.0f;
+    in->vec.f[0] = 7.0f;
+    in->vec.f[1] = 9.0f;
+    in->vec.f[2] = 3.0f;
+    in->vec.f[3] = 1.0f;
+    in->vec.f[4] = 5.0f;
     for(int i=0; i<5; i++) {
-        printf("arr[%d] = %f\n", i, in->arr.fltArr[i]);
+        printf("vec[%d] = %f\n", i, in->vec.f[i]);
     }
-    printFooter(stdout, "psSort", "Create float arrays", true);
+    printFooter(stdout, "psSort", "Create float vectors", true);
 
 
-    // Test B - Sort input float array and put results into output float array
-    printPositiveTestHeader(stdout,"psSort", "Sort float array");
+    // Test B - Sort input float vector and put results into output float vector
+    printPositiveTestHeader(stdout,"psSort", "Sort float vector");
     out = psSort(out, in);
     for(int i=0; i<5; i++) {
-        printf("arr[%d] = %f\n", i, out->arr.fltArr[i]);
+        printf("vec[%d] = %f\n", i, out->vec.f[i]);
     }
-    printFooter(stdout, "psSort", "Sort float array", true);
+    printFooter(stdout, "psSort", "Sort float vector", true);
 
 
-    // Test C - Free float arrays
-    printPositiveTestHeader(stdout,"psSort", "Free float arrays");
-    psFloatArrayFree(in);
-    psFloatArrayFree(out);
+    // Test C - Free float vectors
+    printPositiveTestHeader(stdout,"psSort", "Free float vectors");
+    psVectorFree(in);
+    psVectorFree(out);
     psMemCheckLeaks(0, NULL, stdout);
     int nBad = psMemCheckCorruption(0);
@@ -62,5 +62,6 @@
         printf("ERROR: Found %d bad memory blocks\n", nBad);
     }
-    printFooter(stdout, "psSort", "Free float arrays", true);
+    printFooter(stdout, "psSort", "Free float vectors", true);
 
+    return 0;
 }
@@ -4,12 +4,12 @@
  *
  *  This test driver contains the following tests for psSort test point 1:
- *     A)  Create float arrays
- *     B)  Sort input float array and put results into output float array
- *     C)  Free float arrays
+ *     A)  Create float vectors
+ *     B)  Sort input float vector and put results into output float vector
+ *     C)  Free float vectors
  *
  *  @author  Ross Harman, MHPCC
Index: /trunk/psLib/test/collections/tst_psSort_02.c
===================================================================
--- /trunk/psLib/test/collections/tst_psSort_02.c	(revision 687)
+++ /trunk/psLib/test/collections/tst_psSort_02.c	(revision 688)
@@ -4,12 +4,12 @@
  *
  *  This test driver contains the following tests for psSort test point 2:
  *     A)  Create arrays
  *     B)  Sort integer array of indices based on pre-sort order of floating point array
  *     C)  Free arrays
  *
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.2 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-08 01:19:28 $
+ *  @version $Revision: 1.3 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-05-14 21:04:23 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -23,38 +23,38 @@
          char* argv[])
 {
-    psArray *in = NULL;
-    psArray *out = NULL;
+    psVector *in = NULL;
+    psVector *out = NULL;
 
 
-    // Test A - Create float arrays
-    printPositiveTestHeader(stdout,"psSort", "Create arrays");
-    in = psFloatArrayAlloc(5);
+    // Test A - Create float vectors
+    printPositiveTestHeader(stdout,"psSort", "Create vectors");
+    in = psVectorAlloc(PS_TYPE_FLOAT, 5);
     in->n = 5;
-    out = psIntArrayAlloc(5);
+    out = psVectorAlloc(PS_TYPE_INT32, 5);
     out->n = 5;
-    in->arr.fltArr[0] = 7.0f;
-    in->arr.fltArr[1] = 9.0f;
-    in->arr.fltArr[2] = 3.0f;
-    in->arr.fltArr[3] = 1.0f;
-    in->arr.fltArr[4] = 5.0f;
+    in->vec.f[0] = 7.0f;
+    in->vec.f[1] = 9.0f;
+    in->vec.f[2] = 3.0f;
+    in->vec.f[3] = 1.0f;
+    in->vec.f[4] = 5.0f;
     for(int i=0; i<5; i++) {
-        printf("arr[%d] = %f\n", i, in->arr.fltArr[i]);
+        printf("arr[%d] = %f\n", i, in->vec.f[i]);
     }
-    printFooter(stdout, "psSort", "Create arrays", true);
+    printFooter(stdout, "psSort", "Create vectors", true);
 
 
-    // Test B - Sort integer array of indices based on pre-sort order of floating point array
-    printPositiveTestHeader(stdout,"psSort", "Create sorted index array");
+    // Test B - Sort integer vector of indices based on pre-sort order of floating point vector
+    printPositiveTestHeader(stdout,"psSort", "Create sorted index vector");
     out = psSortIndex(out, in);
     for(int i=0; i<5; i++) {
-        printf("arr[%d] = %d\n", i, out->arr.intArr[i]);
+        printf("arr[%d] = %d\n", i, out->vec.i32[i]);
     }
-    printFooter(stdout, "psSort", "Create sorted index array", true);
+    printFooter(stdout, "psSort", "Create sorted index vector", true);
 
 
-    // Test C - Free arrays
-    printPositiveTestHeader(stdout,"psSort", "Free arrays");
-    psFloatArrayFree(in);
-    psIntArrayFree(out);
+    // Test C - Free vectors
+    printPositiveTestHeader(stdout,"psSort", "Free vectors");
+    psVectorFree(in);
+    psVectorFree(out);
     psMemCheckLeaks(0, NULL, stdout);
     int nBad = psMemCheckCorruption(0);
@@ -62,5 +62,5 @@
         printf("ERROR: Found %d bad memory blocks\n", nBad);
     }
-    printFooter(stdout, "psSort", "Free arrays", true);
+    printFooter(stdout, "psSort", "Free vectors", true);
 
 }
@@ -4,12 +4,12 @@
  *
  *  This test driver contains the following tests for psSort test point 2:
- *     A)  Create arrays
- *     B)  Sort integer array of indices based on pre-sort order of floating point array
- *     C)  Free arrays
+ *     A)  Create vectors
+ *     B)  Sort integer vector of indices based on pre-sort order of floating point vector
+ *     C)  Free vectors
  *
  *  @author  Ross Harman, MHPCC
Index: /trunk/psLib/test/collections/tst_psSort_03.c
===================================================================
--- /trunk/psLib/test/collections/tst_psSort_03.c	(revision 687)
+++ /trunk/psLib/test/collections/tst_psSort_03.c	(revision 688)
@@ -4,12 +4,12 @@
  *
  *  This test driver contains the following tests for psSort test point 3:
  *     A)  Create float arrays of different sizes
  *     B)  Attempt to sort arrays...should get errors
  *     C)  Free float arrays
  *
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.2 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-08 01:19:28 $
+ *  @version $Revision: 1.3 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-05-14 21:04:23 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -23,32 +23,32 @@
          char* argv[])
 {
-    psArray *in = NULL;
-    psArray *out = NULL;
+    psVector *in = NULL;
+    psVector *out = NULL;
 
 
-    // Test A - Create float arrays
-    printPositiveTestHeader(stdout,"psSort", "Create float arrays of different sizes");
-    in = psFloatArrayAlloc(5);
+    // Test A - Create float vectors
+    printPositiveTestHeader(stdout,"psSort", "Create float vectors of different sizes");
+    in = psVectorAlloc(PS_TYPE_FLOAT, 5);
     in->n = 5;
-    out = psFloatArrayAlloc(6);
+    out = psVectorAlloc(PS_TYPE_FLOAT, 6);
     out->n = 6;
     in->n = 5;
     for(int i=0; i<5; i++) {
-        printf("arr[%d] = %f\n", i, in->arr.fltArr[i]);
+        printf("arr[%d] = %f\n", i, in->vec.f[i]);
     }
-    printFooter(stdout, "psSort", "Create float arrays of different sizes", true);
+    printFooter(stdout, "psSort", "Create float vectors of different sizes", true);
 
 
-    // Test B - Sort input float array and put results into output float array
-    printNegativeTestHeader(stdout,"psSort", "Sort float array",
-                            "Input and output array sizes are not equal", 0);
+    // Test B - Sort input float vector and put results into output float vector
+    printNegativeTestHeader(stdout,"psSort", "Sort float vector",
+                            "Input and output vector sizes are not equal", 0);
     out = psSort(out, in);
-    printFooter(stdout, "psSort", "Sort float array", true);
+    printFooter(stdout, "psSort", "Sort float vector", true);
 
 
-    // Test C - Free float arrays
-    printPositiveTestHeader(stdout,"psSort", "Free float arrays");
-    psFloatArrayFree(in);
-    psFloatArrayFree(out);
+    // Test C - Free float vectors
+    printPositiveTestHeader(stdout,"psSort", "Free float vectors");
+    psVectorFree(in);
+    psVectorFree(out);
     psMemCheckLeaks(0, NULL, stdout);
     int nBad = psMemCheckCorruption(0);
@@ -56,5 +56,5 @@
         printf("ERROR: Found %d bad memory blocks\n", nBad);
     }
-    printFooter(stdout, "psSort", "Free float arrays", true);
+    printFooter(stdout, "psSort", "Free float vectors", true);
 
 }
@@ -4,12 +4,12 @@
  *
  *  This test driver contains the following tests for psSort test point 3:
- *     A)  Create float arrays of different sizes
- *     B)  Attempt to sort arrays...should get errors
- *     C)  Free float arrays
+ *     A)  Create float vectors of different sizes
+ *     B)  Attempt to sort vectors...should get errors
+ *     C)  Free float vectors
  *
  *  @author  Ross Harman, MHPCC
Index: /trunk/psLib/test/collections/tst_psSort_04.c
===================================================================
--- /trunk/psLib/test/collections/tst_psSort_04.c	(revision 687)
+++ /trunk/psLib/test/collections/tst_psSort_04.c	(revision 688)
@@ -4,12 +4,12 @@
  *
  *  This test driver contains the following tests for psSort test point 4:
  *     A)  Attempt to sort with null input array
  *     B)  Attempt to sort with null output array 
  *     C)  Free arrays 
  *
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.2 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2004-05-08 01:19:28 $
+ *  @version $Revision: 1.3 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2004-05-14 21:04:23 $
  *
  *  Copyright 2004 Maui High Performance Computing Center, University of Hawaii
@@ -23,25 +23,25 @@
          char* argv[])
 {
-    psArray *badIn = NULL;
-    psArray *badOut = NULL;
-    psArray *goodIn = psFloatArrayAlloc(5);
-    psArray *goodOut = psFloatArrayAlloc(5);
+    psVector *badIn = NULL;
+    psVector *badOut = NULL;
+    psVector *goodIn = psVectorAlloc(PS_TYPE_FLOAT, 5);
+    psVector *goodOut = psVectorAlloc(PS_TYPE_FLOAT, 5);
 
-    // Test A - Attempt to sort with null input array
-    printNegativeTestHeader(stdout,"psSort", "Attempt to sort with null input array",
-                            "Null input array", 0);
+    // Test A - Attempt to sort with null input vector
+    printNegativeTestHeader(stdout,"psSort", "Attempt to sort with null input vector",
+                            "Null input vector", 0);
     goodOut = psSort(goodOut, badIn);
-    printFooter(stdout, "psSort", "Attempt to sort with null input array", true);
+    printFooter(stdout, "psSort", "Attempt to sort with null input vector", true);
 
-    // Test B - Attempt to sort with null output array
-    printNegativeTestHeader(stdout,"psSort", "Attempt to sort with null output array",
-                            "Null output array", 0);
+    // Test B - Attempt to sort with null output vector
+    printNegativeTestHeader(stdout,"psSort", "Attempt to sort with null output vector",
+                            "Null output vector", 0);
     badOut = psSort(badOut, goodIn);
-    printFooter(stdout, "psSort", "Attempt to sort with null output array", true);
+    printFooter(stdout, "psSort", "Attempt to sort with null output vector", true);
 
-    // Test C - Free arrays
-    printPositiveTestHeader(stdout, "psSort", "Free arrays");
-    psFloatArrayFree(goodIn);
-    psFloatArrayFree(goodOut);
+    // Test C - Free vectors
+    printPositiveTestHeader(stdout, "psSort", "Free vectors");
+    psVectorFree(goodIn);
+    psVectorFree(goodOut);
     psMemCheckLeaks(0, NULL, stdout);
     int nBad = psMemCheckCorruption(0);
@@ -4,12 +4,12 @@
  *
  *  This test driver contains the following tests for psSort test point 4:
- *     A)  Attempt to sort with null input array
- *     B)  Attempt to sort with null output array 
- *     C)  Free arrays 
+ *     A)  Attempt to sort with null input vector
+ *     B)  Attempt to sort with null output vector 
+ *     C)  Free vectors 
  *
  *  @author  Ross Harman, MHPCC
